![image](https://img.shields.io/pypi/v/xchat.svg) ![image](https://img.shields.io/travis/yuanjie-ai/xchat.svg) ![image](https://readthedocs.org/projects/xchat/badge/?version=latest)



<h1 align = "center">🔥xchat🔥</h1>

---

# Install

```python
pip install -U xchat
```

# [Docs](https://yuanjie-ai.github.io/xchat/)

# Usages

```
import xchat
```

---

# TODO
